@@ -25,7 +25,7 @@
 #ifndef KGRADIENTDIALOG_H
 #define KGRADIENTDIALOG_H
 
-#include <kdialog.h>
+#include <QDialog>
 #include <QGradient>
 #include <QPushButton>
 #include <QWidget>
@@ -56,7 +56,7 @@ class KGradientEditor : public QWidget
 	Q_PROPERTY( QGradient gradient READ gradient WRITE setGradient USER true )
 	
 	public:
-		KGradientEditor( QWidget * parent );
+		explicit KGradientEditor( QWidget * parent );
 		~KGradientEditor();
 		
 		/**
@@ -171,7 +171,7 @@ class KGradientEditor : public QWidget
  *      ...
  * \endcode
  */
-class KGradientDialog : public KDialog
+class KGradientDialog : public QDialog
 {
 	Q_OBJECT
 			
@@ -210,7 +210,7 @@ class KGradientDialog : public KDialog
 		void gradientChanged( const QGradient & gradient );
 	
 	private:
-		class KColorDialog * m_colorDialog;
+		class QColorDialog * m_colorDialog;
 		KGradientEditor * m_gradient;
 };
 
@@ -227,7 +227,7 @@ class KGradientButton : public QPushButton
 	Q_PROPERTY( QGradient gradient READ gradient WRITE setGradient USER true )
 			
 	public:
-		KGradientButton( QWidget * parent = 0 );
+		explicit KGradientButton( QWidget * parent = 0 );
 		~KGradientButton();
 		
 		/**
