@@ -48,8 +48,8 @@ class MainDlg;
 class QPaintEvent;
 class QTextDocument;
 class KTextEdit;
-class QTime;
 class QMenu;
+class QElapsedTimer;
 
 //@{
 /// Some abbreviations for horizontal and vertical lines.
@@ -545,7 +545,7 @@ class View : public QWidget
 		bool m_stopCalculating;
 		/// the background color of the graph
 		QColor m_backgroundColor;
-		///buffer the current window so all functions don't need to be re-drawed
+		///buffer the current window so all functions don't need to be re-drawn
 		QPixmap buffer;
 		/// the popup menu
 		QMenu *m_popupMenu;
@@ -616,7 +616,7 @@ class View : public QWidget
 		/// for translating the view via dragging
 		QPoint m_prevDragMousePos;
 		/// timer that is started when the mouse is pressed
-		QTime * m_mousePressTimer;
+        QElapsedTimer * m_mousePressTimer;
 		/** Current plot viewport. */
 		const QRectF getViewport();
 		
